ipython_pygments_lexers: Defines a variety of Pygments lexers for highlighting IPython code
===========================================================================================

Description
-----------

Defines a variety of Pygments lexers for highlighting IPython code

License
-------

Upstream Contact
----------------

https://pypi.org/project/ipython-pygments-lexers/

